Learn R Programming

climdex.pcic (version 1.0-3)

climdex.cdd: Maximum Consecutive Dry Days

Description

This function computes the climdex index CDD.

Usage

climdex.cdd(ci, spells.can.span.years = TRUE)

Arguments

ci
Object of type climdexInput.
spells.can.span.years
Whether to allow spells to span years

Value

  • A vector containing the length of the spell for each year.

Details

This function computes the climdex index CDD: the annual maximum length of dry spells, in days. Dry spells are considered to be sequences of days where daily preciptation is less than 1mm per day.

References

http://cccma.seos.uvic.ca/ETCCDMI/list_27_indices.shtml

See Also

climdexInput.raw, climdexInput.csv, spell.length.max.

Examples

Run this code
## Create a climdexInput object from some data already loaded in and
## ready to go.

## Parse the dates into PCICt.
tmax.dates <- as.PCICt(do.call(paste, ec.1018935.tmax[,c("year",
"jday")]), format="%Y %j", cal="gregorian")
tmin.dates <- as.PCICt(do.call(paste, ec.1018935.tmin[,c("year",
"jday")]), format="%Y %j", cal="gregorian")
prec.dates <- as.PCICt(do.call(paste, ec.1018935.prec[,c("year",
"jday")]), format="%Y %j", cal="gregorian")

## Load the data in.
ci <- climdexInput.raw(ec.1018935.tmax$MAX_TEMP,
ec.1018935.tmin$MIN_TEMP, ec.1018935.prec$ONE_DAY_PRECIPITATION,
tmax.dates, tmin.dates, prec.dates, base.range=c(1971, 2000))

## Create an annual timeseries of the CDD index.
cdd <- climdex.cdd(ci)

Run the code above in your browser using DataLab