Learn R Programming

climdex.pcic (version 0.2-1)

climdex.dtr: Mean Diurnal Temperature Range

Description

This function computes the diurnal temperature range on a monthly basis.

Usage

climdex.dtr(ci)

Arguments

ci
Object of type climdexInput.

Value

  • A vector containing the mean monthly diurnal temperature range for each month.

Details

climdex.dtr computes the mean daily diurnal temperature range on a monthly basis.

References

http://cccma.seos.uvic.ca/ETCCDMI/list_27_indices.shtml

See Also

climdexInput.raw, climdexInput.csv.

Examples

Run this code
## Create a climdexInput object from some data already loaded in and
## ready to go.

## Parse the dates into PCICt.
tmax.dates <- as.PCICt(do.call(paste, ec.1018935.tmax[,c("year",
"jday")]), format="%Y %j", cal="gregorian")
tmin.dates <- as.PCICt(do.call(paste, ec.1018935.tmin[,c("year",
"jday")]), format="%Y %j", cal="gregorian")
prec.dates <- as.PCICt(do.call(paste, ec.1018935.prec[,c("year",
"jday")]), format="%Y %j", cal="gregorian")

## Load the data in.
ci <- climdexInput.raw(ec.1018935.tmax$MAX_TEMP,
ec.1018935.tmin$MIN_TEMP, ec.1018935.prec$ONE_DAY_PRECIPITATION,
tmax.dates, tmin.dates, prec.dates, base.range=c(1971, 2000))

## Create a monthly timeseries of mean diurnal temperature range.
dtr <- climdex.dtr(ci)

## Print these out for testing purposes.
dtr

Run the code above in your browser using DataLab