The Expert Team on Climate Change Detection and Indicies (ETCCDI) has created a set of 27 core indices with the intent of capturing the change in the extremes of climate and in selected parameters deemed relevant to other disciplines. These model the following types of parameters:
The climdex.pcic package provides an implementation
of the ETCCDI's 27 core climate change indices. It aims to
be reasonably high performance, to handle non-Gregorian
calendar types, to be as correct as possible given the
definitions of the indices, and to have sufficiently
readable and concise code as to facilitate easy
verification by inspection.
Karl, T.R., N. Nicholls, and A. Ghazi, 1999: CLIVAR/GCOS/WMO workshop on indices and indicators for climate extremes: Workshop summary. Climatic Change, 42, 3-7.
Peterson, T.C., and Coauthors: Report on the Activities of the Working Group on Climate Change Detection and Related Rapporteurs 1998-2001. WMO, Rep. WCDMP-47, WMO-TD 1071, Geneve, Switzerland, 143pp.
Zhang, X., 2005: Avoiding inhomogeneity in percentile-based indices of temperature extremes. Journal of Climate 18.11 (2005):1641-.
climdexInput.raw,
climdexInput.csv,
climdexInput-class.