Learn R Programming

climdex.pcic (version 0.7-2)

climdex.r10mm, climdex.r20mm, climdex.rnnmm: Precipitation Exceeding 10mm, 20mm, and Specified Threshold

Description

These functions compute the climdex indices R10mm, R20mm, and Rnnmm.

Usage

climdex.r10mm(ci)
climdex.r20mm(ci)
climdex.rnnmm(ci, threshold)

Arguments

ci
Object of type climdexInput.
threshold
The threshold to be used for Rnnmm.

Value

  • A vector containing the value of the index for each year.

Details

These functions take a climdexInput object as input and compute the climdex indices R10mm, R20mm, and Rnnmm. These are:
  • R10mm:
{Annual count of days where daily precipitation is more than 10mm.} R20mm:{Annual count of days where daily precipitation is more than 20mm.} Rnnmm:{Annual count of days where daily precipitation is more than the number of millimeters specified by threshold.}

References

http://cccma.seos.uvic.ca/ETCCDMI/list_27_indices.shtml

See Also

climdexInput.raw, climdexInput.csv.

Examples

Run this code
## Create a climdexInput object from some data already loaded in and
## ready to go.

## Parse the dates into PCICt.
tmax.dates <- as.PCICt(do.call(paste, ec.1018935.tmax[,c("year",
"jday")]), format="%Y %j", cal="gregorian")
tmin.dates <- as.PCICt(do.call(paste, ec.1018935.tmin[,c("year",
"jday")]), format="%Y %j", cal="gregorian")
prec.dates <- as.PCICt(do.call(paste, ec.1018935.prec[,c("year",
"jday")]), format="%Y %j", cal="gregorian")

## Load the data in.
ci <- climdexInput.raw(ec.1018935.tmax$MAX_TEMP,
ec.1018935.tmin$MIN_TEMP, ec.1018935.prec$ONE_DAY_PRECIPITATION,
tmax.dates, tmin.dates, prec.dates, base.range=c(1971, 2000))

## Create an annual timeseries of the number of days where
## precipitation exceeds 10mm/day.
r10mm <- climdex.r10mm(ci)

## Create an annual timeseries of the number of days where
## precipitation exceeds 20mm/day.
r20mm <- climdex.r20mm(ci)

## Create an annual timeseries of the number of days where
## precipitation exceeds 25mm/day.
r25mm <- climdex.rnnmm(ci, 25)

## Print these out for testing purposes.
r10mm
r20mm
r25mm

Run the code above in your browser using DataLab