Learn R Programming

climdex.pcic (version 0.1-2)

climdex.r95ptot: climdex.r95ptot

Description

These functions compute the climdex indices R95pTOT, R99pTOT, and PRCPTOT.

Usage

climdex.r95ptot(ci)
climdex.r99ptot(ci)
climdex.prcptot(ci)

Arguments

ci
Object of type climdexInput.

Value

  • A vector containing an annual timeseries of precipitation exceeding the appropriate threshold.

Details

These functions take a climdexInput object as input and compute the climdex indices R95pTOT, R99pTOT, and PRCPTOT. These are:
  • R95pTOT:
{Annual sum of precipitation in days where daily precipitation exceeds the 95th percentile of daily precipitation in the base period.} R99pTOT:{Annual sum of precipitation in days where daily precipitation exceeds the 99th percentile of daily precipitation in the base period.} PRCPTOT:{Annual sum of precipitation in days where daily precipitation is at least 1mm/day.}

References

http://cccma.seos.uvic.ca/ETCCDMI/list_27_indices.shtml

See Also

climdexInput.raw, climdexInput.csv.

Examples

Run this code
## Create a climdexInput object from some data already loaded in and
## ready to go.
## tmax.data, tmin.data, and prec.data are vectors of real numbers.
ci <- climdexInput.raw(tmax.data, tmin.data, prec.data,
tmax.dates, tmin.dates, prec.dates, base.range=c(1971, 2000))

## Create an annual timeseries of the sum of precipitation where
## precipitation exceeds the 95th percentile of precipitation in the
## base period.
r95ptot <- climdex.r95ptot(ci)

## Create an annual timeseries of the sum of precipitation where
## precipitation exceeds the 99th percentile of precipitation in the
## base period.
r99ptot <- climdex.r99ptot(ci)

## Create an annual timeseries of the sum of precipitation where
## precipitation is at least 1mm/day.
prcptot <- climdex.prcptot(ci)

Run the code above in your browser using DataLab