Learn R Programming

climdex.pcic (version 0.1-2)

climdex.rx5day: climdex.rx5day

Description

These functions compute the climdex indices Rx5day and Rx1day.

Usage

climdex.rx5day(ci)
climdex.rx1day(ci)

Arguments

ci
Object of type climdexInput.

Value

  • A vector containing the value of the index for each month of each year.

Details

These functions take a climdexInput object as input and compute the climdex indices Rx5day and Rx1day. These are:
  • Rx5day:
{Monthly maximum 5-day consecutive precipitation.} Rx1day:{Monthly maximum 1-day precipitation.}

References

http://cccma.seos.uvic.ca/ETCCDMI/list_27_indices.shtml

See Also

climdexInput.raw, climdexInput.csv.

Examples

Run this code
## Create a climdexInput object from some data already loaded in and
## ready to go.
## tmax.data, tmin.data, and prec.data are vectors of real numbers.
ci <- climdexInput.raw(tmax.data, tmin.data, prec.data,
tmax.dates, tmin.dates, prec.dates, base.range=c(1971, 2000))

## Create a timeseries of monthly maximum 5-day consecutive
## precipitation.
rx5day <- climdex.rx5day(ci)

## Create a timeseries of monthly maximum 1-day precipitation.
rx1day <- climdex.rx1day(ci)

Run the code above in your browser using DataLab