Learn R Programming

climdex.pcic (version 0.1-2)

climdex.sdii: climdex.sdii

Description

This function computes the climdex index SDII.

Usage

climdex.sdii(ci)

Arguments

ci
Object of type climdexInput.

Value

  • A vector containing the value of the index for each year.

Details

climdex.sdii computes the climdex index SDII, or Simple Precipitation Intensity Index. This is defined as the sum of precipitation in wet days (days with preciptitation over 1mm) during the year divided by the number of wet days in the year.

References

http://cccma.seos.uvic.ca/ETCCDMI/list_27_indices.shtml

See Also

climdexInput.raw, climdexInput.csv.

Examples

Run this code
## Create a climdexInput object from some data already loaded in and
## ready to go.
## tmax.data, tmin.data, and prec.data are vectors of real numbers.
ci <- climdexInput.raw(tmax.data, tmin.data, prec.data,
tmax.dates, tmin.dates, prec.dates, base.range=c(1971, 2000))

## Create a timeseries of annual SDII values.
sdii <- climdex.sdii(ci)

Run the code above in your browser using DataLab