Learn R Programming

climdex.pcic (version 0.1-2)

climdex.tn10p: climdex.tn10p

Description

These functions compute the climdex indices TN10p, TX10p, TN90p, and TN10p.

Usage

climdex.tn10p(ci)
climdex.tx10p(ci)
climdex.tn90p(ci)
climdex.tx90p(ci)

Arguments

ci
Object of type climdexInput.

Value

  • A vector containing the value of the index for each month.

Details

These functions take a climdexInput object as input and compute the climdex indices TN10p, TX10p, TN90p, and TN10p. These are:
  • TN10p:
{Monthly percent of values below the 10th percentile of baseline daily minimum temperature.} TX10p:{Monthly percent of values below the 10th percentile of baseline daily maximum temperature.} TN90p:{Monthly percent of values above the 90th percentile of baseline daily minimum temperature.} TX90p:{Monthly percent of values above the 90th percentile of baseline daily maximum temperature.}

References

http://cccma.seos.uvic.ca/ETCCDMI/list_27_indices.shtml

Zhang, X., 2005: Avoiding inhomogeneity in percentile-based indices of temperature extremes. Journal of Climate 18.11 (2005):1641-.

See Also

climdexInput.raw, climdexInput.csv.

Examples

Run this code
## Create a climdexInput object from some data already loaded in and
## ready to go.
## tmax.data, tmin.data, and prec.data are vectors of real numbers.
ci <- climdexInput.raw(tmax.data, tmin.data, prec.data,
tmax.dates, tmin.dates, prec.dates, base.range=c(1971, 2000))

## Create a monthly timeseries of percentage of daily minimum
## temperature values which fall below the 10th percentile.
tn10p <- climdex.tn10p(ci)

## Create a monthly timeseries of percentage of daily maximum
## temperature values which fall below the 10th percentile.
tx10p <- climdex.tx10p(ci)

## Create a monthly timeseries of percentage of daily minimum
## temperature values which are above the 90th percentile.
tn90p <- climdex.tn90p(ci)

## Create a monthly timeseries of percentage of daily maximum
## temperature values which are above the 90th percentile.
tx90p <- climdex.tx90p(ci)

Run the code above in your browser using DataLab