## Create a climdexInput object from some data already loaded in and
## ready to go.
## Parse the dates into PCICt.
tmax.dates <- as.PCICt(do.call(paste, ec.1018935.tmax[,c("year",
"jday")]), format="%Y %j", cal="gregorian")
tmin.dates <- as.PCICt(do.call(paste, ec.1018935.tmin[,c("year",
"jday")]), format="%Y %j", cal="gregorian")
prec.dates <- as.PCICt(do.call(paste, ec.1018935.prec[,c("year",
"jday")]), format="%Y %j", cal="gregorian")
## Load the data in.
ci <- climdexInput.raw(ec.1018935.tmax$MAX_TEMP,
ec.1018935.tmin$MIN_TEMP, ec.1018935.prec$ONE_DAY_PRECIPITATION,
tmax.dates, tmin.dates, prec.dates, base.range=c(1971, 2000))
## Create a monthly timeseries of percentage of daily minimum
## temperature values which fall below the 10th percentile.
tn10p <- climdex.tn10p(ci)
## Create a monthly timeseries of percentage of daily maximum
## temperature values which fall below the 10th percentile.
tx10p <- climdex.tx10p(ci)
## Create a monthly timeseries of percentage of daily minimum
## temperature values which are above the 90th percentile.
tn90p <- climdex.tn90p(ci)
## Create a monthly timeseries of percentage of daily maximum
## temperature values which are above the 90th percentile.
tx90p <- climdex.tx90p(ci)
## Print these out for testing purposes.
tn10p
tx10p
tn90p
tx90pRun the code above in your browser using DataLab