Learn R Programming

climdex.pcic (version 0.6-2)

climdex.tn10p, climdex.tx10p, climdex.tn90p, climdex.tx90p: Percent of Values Above/Below 10th/90th Percentile Temperature

Description

These functions compute the climdex indices TN10p, TX10p, TN90p, and TN10p.

Usage

climdex.tn10p(ci, freq=c("monthly", "annual"))
climdex.tx10p(ci, freq=c("monthly", "annual"))
climdex.tn90p(ci, freq=c("monthly", "annual"))
climdex.tx90p(ci, freq=c("monthly", "annual"))

Arguments

ci
Object of type climdexInput.
freq
Time frequency to aggregate to.

Value

  • A vector containing a timeseries containing values of the index on a monthly or annual timescale.

Details

These functions take a climdexInput object as input and compute the climdex indices TN10p, TX10p, TN90p, and TN10p. These are:
  • TN10p:
{Monthly or annual percent of values below the 10th percentile of baseline daily minimum temperature.} TX10p:{Monthly or annual percent of values below the 10th percentile of baseline daily maximum temperature.} TN90p:{Monthly or annual percent of values above the 90th percentile of baseline daily minimum temperature.} TX90p:{Monthly or annual percent of values above the 90th percentile of baseline daily maximum temperature.}

References

http://cccma.seos.uvic.ca/ETCCDMI/list_27_indices.shtml

Zhang, X., 2005: Avoiding inhomogeneity in percentile-based indices of temperature extremes. Journal of Climate 18.11 (2005):1641-.

See Also

climdexInput.raw, climdexInput.csv.

Examples

Run this code
## Create a climdexInput object from some data already loaded in and
## ready to go.

## Parse the dates into PCICt.
tmax.dates <- as.PCICt(do.call(paste, ec.1018935.tmax[,c("year",
"jday")]), format="%Y %j", cal="gregorian")
tmin.dates <- as.PCICt(do.call(paste, ec.1018935.tmin[,c("year",
"jday")]), format="%Y %j", cal="gregorian")
prec.dates <- as.PCICt(do.call(paste, ec.1018935.prec[,c("year",
"jday")]), format="%Y %j", cal="gregorian")

## Load the data in.
ci <- climdexInput.raw(ec.1018935.tmax$MAX_TEMP,
ec.1018935.tmin$MIN_TEMP, ec.1018935.prec$ONE_DAY_PRECIPITATION,
tmax.dates, tmin.dates, prec.dates, base.range=c(1971, 2000))

## Create a monthly timeseries of percentage of daily minimum
## temperature values which fall below the 10th percentile.
tn10p <- climdex.tn10p(ci)

## Create a monthly timeseries of percentage of daily maximum
## temperature values which fall below the 10th percentile.
tx10p <- climdex.tx10p(ci)

## Create a monthly timeseries of percentage of daily minimum
## temperature values which are above the 90th percentile.
tn90p <- climdex.tn90p(ci)

## Create a monthly timeseries of percentage of daily maximum
## temperature values which are above the 90th percentile.
tx90p <- climdex.tx90p(ci)

## Print these out for testing purposes.
tn10p
tx10p
tn90p
tx90p

Run the code above in your browser using DataLab