Learn R Programming

climdex.pcic (version 0.7-4)

climdex.txx, climdex.tnx, climdex.txn, climdex.tnn: Monthly Maximum/Minimum of Daily Maximum/Minimum Temperature

Description

These functions compute the climdex indices TXx, TNx, TXn, and TNn.

Usage

climdex.txx(ci, freq=c("monthly", "annual"))
climdex.tnx(ci, freq=c("monthly", "annual"))
climdex.txn(ci, freq=c("monthly", "annual"))
climdex.tnn(ci, freq=c("monthly", "annual"))

Arguments

ci
Object of type climdexInput.
freq
Time frequency to aggregate to.

Value

  • A vector containing the value of the index for each month.

Details

These functions take a climdexInput object as input and compute the climdex indices TXx, TNx, TXn, and TNn. These are:
  • TXx:
{Monthly or annual maximum of daily maximum temperature.} TNx:{Monthly or annual maximum of daily minimum temperature.} TXn:{Monthly or annual minimum of daily maximum temperature.} TNn:{Monthly or annual minimum of daily minimum temperature.}

References

http://cccma.seos.uvic.ca/ETCCDMI/list_27_indices.shtml

See Also

climdexInput.raw, climdexInput.csv.

Examples

Run this code
## Create a climdexInput object from some data already loaded in and
## ready to go.

## Parse the dates into PCICt.
tmax.dates <- as.PCICt(do.call(paste, ec.1018935.tmax[,c("year",
"jday")]), format="%Y %j", cal="gregorian")
tmin.dates <- as.PCICt(do.call(paste, ec.1018935.tmin[,c("year",
"jday")]), format="%Y %j", cal="gregorian")
prec.dates <- as.PCICt(do.call(paste, ec.1018935.prec[,c("year",
"jday")]), format="%Y %j", cal="gregorian")

## Load the data in.
ci <- climdexInput.raw(ec.1018935.tmax$MAX_TEMP,
ec.1018935.tmin$MIN_TEMP, ec.1018935.prec$ONE_DAY_PRECIPITATION,
tmax.dates, tmin.dates, prec.dates, base.range=c(1971, 2000))

## Create a monthly timeseries of maximum daily maximum temperature.
txx <- climdex.txx(ci)

## Create a monthly timeseries of maximum daily minimum temperature.
tnx <- climdex.tnx(ci)

## Create a monthly timeseries of minimum daily maximum temperature.
txn <- climdex.txn(ci)

## Create a monthly timeseries of minimum daily minimum temperature.
tnn <- climdex.tnn(ci)

## Print these out for testing purposes.
txx
tnx
txn
tnn

Run the code above in your browser using DataLab