Learn R Programming

climdex.pcic (version 0.1-2)

climdex.wsdi: climdex.wsdi

Description

These functions compute the climdex indices WSDI and CSDI.

Usage

climdex.wsdi(ci)
climdex.csdi(ci)

Arguments

ci
Object of type climdexInput.

Value

  • A vector containing the value of the index for each year.

Details

These functions take a climdexInput object as input and compute the climdex indices WSDI and CSDI. These are:
  • WSDI:
{Warm Spell Duration Index.} CSDI:{Cold Spell Duration Index.}

References

http://cccma.seos.uvic.ca/ETCCDMI/list_27_indices.shtml

See Also

climdexInput.raw, climdexInput.csv.

Examples

Run this code
## Create a climdexInput object from some data already loaded in and
## ready to go.
## tmax.data, tmin.data, and prec.data are vectors of real numbers.
ci <- climdexInput.raw(tmax.data, tmin.data, prec.data,
tmax.dates, tmin.dates, prec.dates, base.range=c(1971, 2000))

## Create an annual timeseries of the warm spell duration index.
wsdi <- climdex.wsdi(ci)

## Create an annual timeseries of the cold spell duration index.
csdi <- climdex.csdi(ci)

Run the code above in your browser using DataLab