Learn R Programming

climdex.pcic (version 1.1-1)

get.last.monthday.of.year: Get the last month and day of the year

Description

Get the last month and day of the year as a character sting, separated by the specified separator.

Usage

get.last.monthday.of.year(d, sep = "-")

Arguments

d
An exemplar date.
sep
Separator to use.

Value

  • A string (like "12-30", or "12-31")

Details

This is a utility function necessitated by 360-day calendars. Works on PCICt objects.

Examples

Run this code
library(PCICt)
last.mday <- get.last.monthday.of.year(as.PCICt("2011-01-01", cal="360"))

Run the code above in your browser using DataLab