get.series.lengths.at.ends: Get series length at ends
Description
This function takes a series of boolean values and
returns a list of integers of the same length
corresponding to the lengths at the ends of sequences of
TRUE values.
Usage
get.series.lengths.at.ends(x, na.value = FALSE)
Arguments
x
Sequence of booleans.
na.value
Value to replace NAs with.
Value
A vector consisting of the lengths of sequences of TRUE
values at the location of the last TRUE value in the
sequence, and zeroes elsewhere.
Details
It can often be useful to know how long a series of
boolean values is. This function provides a method of
knowing where and how long such sequences are.
## Get lengths of sequences of TRUE values in a sequenceseries.lengths <- get.series.lengths.at.ends(c(TRUE, TRUE, TRUE, FALSE,
TRUE, FALSE, TRUE, TRUE, TRUE, TRUE, FALSE))