Learn R Programming

climdex.pcic (version 0.1-2)

climdex.cdd: climdex.cdd

Description

These functions compute the climdex indices CDD and CWD.

Usage

climdex.cdd(ci)
climdex.cwd(ci)

Arguments

ci
Object of type climdexInput.

Value

  • A vector containing the length of the dry or wet spell for each year.

Details

These functions take a climdexInput object as input and compute the climdex indices CDD and CWD. These are:
  • CDD:
{Annual maximum length of dry spell, in days.} CWD:{Annual maximum length of wet spell, in days.}

References

http://cccma.seos.uvic.ca/ETCCDMI/list_27_indices.shtml

See Also

climdexInput.raw, climdexInput.csv.

Examples

Run this code
## Create a climdexInput object from some data already loaded in and
## ready to go.
## tmax.data, tmin.data, and prec.data are vectors of real numbers.
ci <- climdexInput.raw(tmax.data, tmin.data, prec.data,
tmax.dates, tmin.dates, prec.dates, base.range=c(1971, 2000))

## Create an annual timeseries of the number of consecutive days where
## precipitation was less than 1mm/day.
cdd <- climdex.cdd(ci)

## Create an annual timeseries of the number of consecutive days where
## precipitation was at least 1mm/day.
cwd <- climdex.cwd(ci)

Run the code above in your browser using DataLab