## Create a climdexInput object from some data already loaded in and
## ready to go.
## tmax.data, tmin.data, and prec.data are vectors of real numbers.
ci <- climdexInput.raw(tmax.data, tmin.data, prec.data,
tmax.dates, tmin.dates, prec.dates, base.range=c(1971, 2000))
## Create an annual timeseries of the number of consecutive days where
## precipitation was less than 1mm/day.
cdd <- climdex.cdd(ci)
## Create an annual timeseries of the number of consecutive days where
## precipitation was at least 1mm/day.
cwd <- climdex.cwd(ci)Run the code above in your browser using DataLab