Learn R Programming

climdex.pcic (version 0.1-2)

climdex.dtr: climdex.dtr

Description

This function computes the diurnal temperature range on a monthly basis.

Usage

climdex.dtr(ci)

Arguments

ci
Object of type climdexInput.

Value

  • A vector containing the mean monthly diurnal temperature range for each month.

Details

climdex.dtr computes the mean daily diurnal temperature range on a monthly basis.

References

http://cccma.seos.uvic.ca/ETCCDMI/list_27_indices.shtml

See Also

climdexInput.raw, climdexInput.csv.

Examples

Run this code
## Create a climdexInput object from some data already loaded in and
## ready to go.
## tmax.data, tmin.data, and prec.data are vectors of real numbers.
ci <- climdexInput.raw(tmax.data, tmin.data, prec.data,
tmax.dates, tmin.dates, prec.dates, base.range=c(1971, 2000))

## Create a monthly timeseries of mean diurnal temperature range.
dtr <- climdex.dtr(ci)

Run the code above in your browser using DataLab