## Create a climdexInput object from some data already loaded in and
## ready to go.
## tmax.data, tmin.data, and prec.data are vectors of real numbers.
ci <- climdexInput.raw(tmax.data, tmin.data, prec.data,
tmax.dates, tmin.dates, prec.dates, base.range=c(1971, 2000))
## Create a monthly timeseries of mean diurnal temperature range.
dtr <- climdex.dtr(ci)Run the code above in your browser using DataLab