Learn R Programming

climdex.pcic (version 0.1-3)

climdex.gsl: climdex.gsl

Description

This function computes the growing season length (GSL) given the input.

Usage

climdex.gsl(ci)

Arguments

ci
Object of type climdexInput.

Value

  • A vector containing the number of days meeting the criteria of the index for each year.

Details

This function takes a climdexInput object as input and computes the growing season length based on this data.

Growing season length as defined by the climdex indices is the number of days between the start of the first spell of warm days in the first half of the year, and the start of the first spell of cold days in the second half of the year. Spells of warm days are defined as six or more days with mean temperature above 5 degrees Celsius; spells of cold days are defined as six or more days with a mean temperature below 5 degrees Celsius.

References

http://cccma.seos.uvic.ca/ETCCDMI/list_27_indices.shtml

See Also

climdexInput.raw, climdexInput.csv.

Examples

Run this code
## Create a climdexInput object from some data already loaded in and
## ready to go.
## tmax.data, tmin.data, and prec.data are vectors of real numbers.
ci <- climdexInput.raw(tmax.data, tmin.data, prec.data,
tmax.dates, tmin.dates, prec.dates, base.range=c(1971, 2000))

## Create an annual timeseries of the growing season length in days.
gsl <- climdex.gsl(ci)

Run the code above in your browser using DataLab