## Create a climdexInput object from some data already loaded in and
## ready to go.
## tmax.data, tmin.data, and prec.data are vectors of real numbers.
ci <- climdexInput.raw(tmax.data, tmin.data, prec.data,
tmax.dates, tmin.dates, prec.dates, base.range=c(1971, 2000))
## Create an annual timeseries of the number of days where
## precipitation exceeds 10mm/day.
r10mm <- climdex.r10mm(ci)
## Create an annual timeseries of the number of days where
## precipitation exceeds 20mm/day.
r20mm <- climdex.r20mm(ci)
## Create an annual timeseries of the number of days where
## precipitation exceeds 25mm/day.
r25mm <- climdex.rnnmm(ci, 25)Run the code above in your browser using DataLab