## Create a climdexInput object from some data already loaded in and
## ready to go.
## Parse the dates into PCICt.
tmax.dates <- as.PCICt(do.call(paste, ec.1018935.tmax[,c("year",
"jday")]), format="%Y %j", cal="gregorian")
tmin.dates <- as.PCICt(do.call(paste, ec.1018935.tmin[,c("year",
"jday")]), format="%Y %j", cal="gregorian")
prec.dates <- as.PCICt(do.call(paste, ec.1018935.prec[,c("year",
"jday")]), format="%Y %j", cal="gregorian")
## Load the data in.
ci <- climdexInput.raw(ec.1018935.tmax$MAX_TEMP,
ec.1018935.tmin$MIN_TEMP, ec.1018935.prec$ONE_DAY_PRECIPITATION,
tmax.dates, tmin.dates, prec.dates, base.range=c(1971, 2000))
## Create an annual timeseries of the number of days where
## precipitation exceeds 10mm/day.
r10mm <- climdex.r10mm(ci)
## Create an annual timeseries of the number of days where
## precipitation exceeds 20mm/day.
r20mm <- climdex.r20mm(ci)
## Create an annual timeseries of the number of days where
## precipitation exceeds 25mm/day.
r25mm <- climdex.rnnmm(ci, 25)
## Print these out for testing purposes.
r10mm
r20mm
r25mmRun the code above in your browser using DataLab