## Create a climdexInput object from some data already loaded in and
## ready to go.
## tmax.data, tmin.data, and prec.data are vectors of real numbers.
ci <- climdexInput.raw(tmax.data, tmin.data, prec.data,
tmax.dates, tmin.dates, prec.dates, base.range=c(1971, 2000))
## Create an annual timeseries of the number of frost days.
fd <- climdex.fd(ci)
## Create an annual timeseries of the number of summer days.
su <- climdex.su(ci)
## Create an annual timeseries of the number of icing days.
id <- climdex.id(ci)
## Create an annual timeseries of the number of tropical nights.
tr <- climdex.tr(ci)Run the code above in your browser using DataLab